@@ -76,9 +76,12 @@ REGISTERED = (
     [libcst.AsName, st.from_type(libcst.Name)],
     [libcst.AnnAssign, infer, infer, infer],
     [libcst.Assign, nonempty_seq(libcst.AssignTarget)],
+    [libcst.Await, infer, st.just(()), st.just(()), nonempty_whitespace],
+    [libcst.Attribute, infer, infer, infer],
     [libcst.Comparison, infer, nonempty_seq(libcst.ComparisonTarget)],
     [libcst.Decorator, st.from_type(libcst.Name) | st.from_type(libcst.Attribute)],
     [libcst.EmptyLine, infer, infer, infer],
+    [libcst.ExceptHandler, infer, infer, infer, infer, nonempty_whitespace, infer],
     [libcst.Global, nonempty_seq(libcst.NameItem)],
     [libcst.Import, nonempty_seq(libcst.ImportAlias)],
     [
@@ -132,6 +135,7 @@ for node_type, *strats in REGISTERED:
 # If a Try node has no `except` clause, it *must* have a `finally` clause and
 # *must not* have an `else` clause.  With one or more except clauses, it may
 # have an else and/or a finally, or neither.
+# The .map() ensures that any bare-`except:` clauses are ordered last.
 st.register_type_strategy(
     libcst.Try,
     st.builds(libcst.Try, finalbody=st.from_type(libcst.Finally))
@@ -142,7 +146,7 @@ st.register_type_strategy(
             st.deferred(lambda: st.from_type(libcst.ExceptHandler)),
             min_size=1,
             unique_by=lambda caught: caught.type,
-        ),
+        ).map(lambda xs: sorted(xs, key=lambda x: x.type is None)),
         orelse=infer,
         finalbody=infer,
     ),
@@ -210,6 +214,10 @@ def boolean_op_with_whitespace(draw):  # type: ignore
 
 st.register_type_strategy(libcst.BooleanOperation, boolean_op_with_whitespace())
 
+st.register_type_strategy(
+    libcst.ComparisonTarget, builds_filtering(libcst.ComparisonTarget)
+)
+
 
 # TODO: this works pretty well, but it's also a pretty poor trick for performance.
 #       Instead of filtering, we should continue expanding the specific node
